package com.rwk.system.mapper;

import java.util.List;
import com.rwk.system.domain.RwkAddressGroup;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author ruoyi
 * @date 2024-12-16
 */
public interface RwkAddressGroupMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public RwkAddressGroup selectRwkAddressGroupById(Long id);

    /**
     * 查询分组列表
     */
    public List<RwkAddressGroup> selectRwkAddressGroupList(String username);

    public List<RwkAddressGroup> selectRwkAddressGroupListAllByDept(Long deptId);
    public List<RwkAddressGroup> selectRwkAddressGroupListLackByDept(Long deptId);

    /**
     * 新增【请填写功能名称】
     * 
     * @param rwkAddressGroup 【请填写功能名称】
     * @return 结果
     */
    public int insertRwkAddressGroup(RwkAddressGroup rwkAddressGroup);

    /**
     * 修改【请填写功能名称】
     * 
     * @param rwkAddressGroup 【请填写功能名称】
     * @return 结果
     */
    public int updateRwkAddressGroup(RwkAddressGroup rwkAddressGroup);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteRwkAddressGroupById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRwkAddressGroupByIds(String[] ids);
}
